@@ -47,9 +47,11 @@ const (
 	Priority = -1000
 
 	// Configuration keys
-	configKeyEnabled  = "operator.process.emitstats"
-	configKeyInterval = "operator.process.interval"
-	configKeyFields   = "operator.process.fields"
+	configKeyEnabled       = "operator.process.emitstats"
+	configKeyInterval      = "operator.process.interval"
+	configKeyFirstInterval = "operator.process.first-interval"
+	configKeyFields        = "operator.process.fields"
+	configKeyCount         = "operator.process.count"
 
 	// Default values
 	defaultInterval = 60 * time.Second
@@ -58,11 +60,16 @@ const (
 	fieldPID              = "pid"
 	fieldPPID             = "ppid"
 	fieldComm             = "comm"
+	fieldNice             = "nice"
+	fieldPriority         = "priority"
+	fieldCPUTime          = "cpuTime"
+	fieldCPUTimeStr       = "cpuTimeStr"
 	fieldCPUUsage         = "cpuUsage"
 	fieldCPUUsageRelative = "cpuUsageRelative"
 	fieldMemoryRSS        = "memoryRSS"
 	fieldMemoryVirtual    = "memoryVirtual"
 	fieldMemoryRelative   = "memoryRelative"
+	fieldMemoryShared     = "memoryShared"
 	fieldThreadCount      = "threadCount"
 	fieldState            = "state"
 	fieldUid              = "uid"
@@ -115,6 +122,9 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 		gadgetCtx.Logger().Debugf("Using default interval: %s", interval)
 	}
 
+	count := viperConfig.GetInt(configKeyCount)
+	firstInterval := viperConfig.GetDuration(configKeyFirstInterval)
+
 	// Get fields from config
 	fields := viperConfig.GetStringSlice(configKeyFields)
 
@@ -125,15 +135,19 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 			fieldPID,
 			fieldPPID,
 			fieldComm,
+			fieldPriority,
+			fieldNice,
 			fieldCPUUsage,
 			fieldCPUUsageRelative,
 			fieldMemoryRSS,
 			fieldMemoryVirtual,
+			fieldMemoryShared,
 			fieldMemoryRelative,
 			fieldThreadCount,
 			fieldState,
 			fieldUid,
 			fieldStartTime,
+			fieldCPUTime,
 		}
 	}
 
@@ -146,9 +160,11 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 	ds.AddAnnotation(api.FetchIntervalAnnotation, interval.String())
 
 	instance := &processOperatorInstance{
-		interval:   interval,
-		done:       make(chan struct{}),
-		dataSource: ds,
+		interval:      interval,
+		count:         count,
+		firstInterval: firstInterval,
+		done:          make(chan struct{}),
+		dataSource:    ds,
 	}
 
 	// Add fields to the data source based on enabled fields
@@ -178,6 +194,40 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 			if err != nil {
 				return nil, fmt.Errorf("adding comm field: %w", err)
 			}
+		case fieldNice:
+			instance.niceField, err = ds.AddField(fieldNice, api.Kind_Int8, datasource.WithAnnotations(map[string]string{
+				metadatav1.ColumnsAlignmentAnnotation: "right",
+				metadatav1.DescriptionAnnotation:      "The nice value of the process.",
+			}))
+			if err != nil {
+				return nil, fmt.Errorf("adding nice field: %w", err)
+			}
+			requireCPUInfo = true
+		case fieldPriority:
+			instance.priorityField, err = ds.AddField(fieldPriority, api.Kind_Int8, datasource.WithAnnotations(map[string]string{
+				metadatav1.ColumnsAlignmentAnnotation: "right",
+				metadatav1.DescriptionAnnotation:      "The priority of the process.",
+			}))
+			if err != nil {
+				return nil, fmt.Errorf("adding priority field: %w", err)
+			}
+			requireCPUInfo = true
+		case fieldCPUTime:
+			instance.cpuTimeField, err = ds.AddField(fieldCPUTime, api.Kind_Int64, datasource.WithAnnotations(map[string]string{
+				metadatav1.ColumnsHiddenAnnotation: "true",
+				metadatav1.DescriptionAnnotation:   "Total CPU time",
+			}))
+			if err != nil {
+				return nil, fmt.Errorf("adding cpuTime field: %w", err)
+			}
+			instance.cpuTimeStrField, err = ds.AddField(fieldCPUTimeStr, api.Kind_String, datasource.WithAnnotations(map[string]string{
+				metadatav1.DescriptionAnnotation:      "Total CPU time, formatted as duration",
+				metadatav1.ColumnsAlignmentAnnotation: "right",
+				metadatav1.ColumnsMaxWidthAnnotation:  "12",
+			}))
+			if err != nil {
+				return nil, fmt.Errorf("adding cpuTimeStr field: %w", err)
+			}
 		case fieldCPUUsage:
 			instance.cpuField, err = ds.AddField(fieldCPUUsage, api.Kind_Float64, datasource.WithAnnotations(map[string]string{
 				metadatav1.ColumnsPrecisionAnnotation: "1",
@@ -194,7 +244,7 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 				metadatav1.ColumnsPrecisionAnnotation: "1",
 				metadatav1.ColumnsAlignmentAnnotation: "right",
 				metadatav1.DescriptionAnnotation:      "The CPU usage percentage relative to the number of CPUs available.",
-				metadatav1.ColumnsMaxWidthAnnotation:  "16",
+				metadatav1.ColumnsMaxWidthAnnotation:  "8",
 			}))
 			if err != nil {
 				return nil, fmt.Errorf("adding cpuUsageRelative field: %w", err)
@@ -227,11 +277,22 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 				metadatav1.ColumnsAlignmentAnnotation: "right",
 				metadatav1.ColumnsPrecisionAnnotation: "1",
 				metadatav1.DescriptionAnnotation:      "Percentage of RSS memory used relative to available memory.",
-				metadatav1.ColumnsMaxWidthAnnotation:  "14",
+				metadatav1.ColumnsMaxWidthAnnotation:  "8",
 			}))
 			if err != nil {
 				return nil, fmt.Errorf("adding memoryRelative field: %w", err)
 			}
+		case fieldMemoryShared:
+			instance.memorySharedField, err = ds.AddField(fieldMemoryShared+"_raw", api.Kind_Uint64,
+				datasource.WithAnnotations(map[string]string{
+					metadatav1.ColumnsAlignmentAnnotation: "right",
+					metadatav1.DescriptionAnnotation:      "The Shared Memory Size of the process in bytes.",
+				}),
+				datasource.WithTags("type:gadget_bytes"),
+			)
+			if err != nil {
+				return nil, fmt.Errorf("adding memoryShared field: %w", err)
+			}
 		case fieldThreadCount:
 			instance.threadCountField, err = ds.AddField(fieldThreadCount, api.Kind_Int32, datasource.WithAnnotations(map[string]string{
 				metadatav1.ColumnsAlignmentAnnotation: "right",
@@ -270,6 +331,7 @@ func (p *processOperator) InstantiateDataOperator(gadgetCtx operators.GadgetCont
 			instance.startTimeStrField, err = ds.AddField(fieldStartTimeStr, api.Kind_String, datasource.WithAnnotations(map[string]string{
 				metadatav1.DescriptionAnnotation:     "The time when the process started, represented as a formatted date-time string in RFC3339 format (e.g., \"2023-06-15T14:30:45Z\").",
 				metadatav1.ColumnsEllipsisAnnotation: "start",
+				metadatav1.ColumnsMaxWidthAnnotation: "25",
 			}))
 			if err != nil {
 				return nil, fmt.Errorf("adding startTimeStr field: %w", err)
@@ -300,16 +362,23 @@ func (p *processOperator) Priority() int {
 
 type processOperatorInstance struct {
 	interval            time.Duration
+	count               int
+	firstInterval       time.Duration
 	dataSource          datasource.DataSource
 	done                chan struct{}
 	wg                  sync.WaitGroup
 	pidField            datasource.FieldAccessor
 	ppidField           datasource.FieldAccessor
 	commField           datasource.FieldAccessor
+	priorityField       datasource.FieldAccessor
+	niceField           datasource.FieldAccessor
 	cpuField            datasource.FieldAccessor
+	cpuTimeField        datasource.FieldAccessor
+	cpuTimeStrField     datasource.FieldAccessor
 	cpuRelativeField    datasource.FieldAccessor
 	memoryRSSField      datasource.FieldAccessor
 	memoryVirtualField  datasource.FieldAccessor
+	memorySharedField   datasource.FieldAccessor
 	memoryRelativeField datasource.FieldAccessor
 	threadCountField    datasource.FieldAccessor
 	stateField          datasource.FieldAccessor
@@ -404,9 +473,26 @@ func (p *processOperatorInstance) monitorProcesses(gadgetCtx operators.GadgetCon
 		gadgetCtx.Logger().Errorf("Error collecting process info: %v", err)
 	}
 
+	// Run a first interval, if configured, to provide early data
+	if p.firstInterval > 0 {
+		timer := time.NewTimer(p.firstInterval)
+		defer timer.Stop()
+		select {
+		case <-p.done:
+			return
+		case <-timer.C:
+			err := p.collectProcessInfo(gadgetCtx, true)
+			if err != nil {
+				gadgetCtx.Logger().Errorf("Error collecting process info: %v", err)
+			}
+		}
+	}
+
 	ticker := time.NewTicker(p.interval)
 	defer ticker.Stop()
 
+	count := 0
+
 	for {
 		select {
 		case <-p.done:
@@ -416,6 +502,10 @@ func (p *processOperatorInstance) monitorProcesses(gadgetCtx operators.GadgetCon
 			if err != nil {
 				gadgetCtx.Logger().Errorf("Error collecting process info: %v", err)
 			}
+			count++
+			if p.count > 0 && count >= p.count {
+				return
+			}
 		}
 	}
 }
@@ -520,6 +610,14 @@ func (p *processOperatorInstance) collectProcessInfo(gadgetCtx operators.GadgetC
 			p.commField.PutString(packet, proc.Comm)
 		}
 
+		if p.priorityField != nil {
+			p.priorityField.PutInt8(packet, int8(proc.Priority))
+		}
+
+		if p.niceField != nil {
+			p.niceField.PutInt8(packet, int8(proc.Nice))
+		}
+
 		if p.cpuField != nil {
 			p.cpuField.PutFloat64(packet, proc.CPUUsage)
 		}
@@ -536,6 +634,10 @@ func (p *processOperatorInstance) collectProcessInfo(gadgetCtx operators.GadgetC
 			p.memoryVirtualField.PutUint64(packet, proc.MemoryVirtual)
 		}
 
+		if p.memorySharedField != nil {
+			p.memorySharedField.PutUint64(packet, proc.MemoryShared)
+		}
+
 		if p.memoryRelativeField != nil {
 			p.memoryRelativeField.PutFloat64(packet, proc.MemoryRelative)
 		}
@@ -557,6 +659,16 @@ func (p *processOperatorInstance) collectProcessInfo(gadgetCtx operators.GadgetC
 			p.startTimeStrField.PutString(packet, proc.StartTimeStr.Format(time.RFC3339))
 		}
 
+		if p.cpuTimeField != nil {
+			p.cpuTimeField.PutUint64(packet, proc.CPUTime)
+
+			d := time.Duration(proc.CPUTime) * time.Millisecond * 10
+			mins := int(d.Minutes())
+			secs := int(d.Seconds()) % 60
+			ms := int(d.Milliseconds() % 1000)
+			p.cpuTimeStrField.PutString(packet, strconv.Itoa(mins)+":"+pad2(secs)+"."+pad3(ms))
+		}
+
 		// Always emit mount namespace ID
 		p.mountNsIDField.PutUint64(packet, proc.MountNsID)
 
